@@ -6,6 +6,8 @@
 zonal <- function(x, zones, stat='mean', digits=0, na.rm=TRUE, progress='') {
 
 	compare(c(x, zones))
+	stopifnot(hasValues(zones))
+	stopifnot(hasValues(x))
 	
 	layernames <- layerNames(x)
 	
@@ -28,7 +30,7 @@ zonal <- function(x, zones, stat='mean', digits=0, na.rm=TRUE, progress='') {
 	} else {
 		
 		if (class(stat) != 'character') {
-			stop("RasterLayers are too large.\n You can use stat='sum', 'mean', 'min', or 'max', but not a function")
+			stop("RasterLayers cannot be processed in memory.\n You can use stat='sum', 'mean', 'min', or 'max', but not a function")
 		}
 		if (! stat %in% c('sum', 'mean', 'min', 'max')) {
 			stop("stat can be 'sum', 'mean', 'min', or 'max'")
@@ -54,9 +56,12 @@ zonal <- function(x, zones, stat='mean', digits=0, na.rm=TRUE, progress='') {
 			if (nrow(d) > 0) {
 				alltab <- rbind(alltab, aggregate(d[,1:(ncol(d)-1)], by=list(d[,ncol(d)]), FUN=fun, na.rm=na.rm)) 
 				if (counts) {
-					cnttab <- rbind(cnttab, aggregate(d[,1:(ncol(d)-1)], by=list(d[,ncol(d)]), FUN=length, na.rm=na.rm)) 
+					if (na.rm) {
+						cnttab <- rbind(cnttab, aggregate(d[,1:(ncol(d)-1)], by=list(d[,ncol(d)]), FUN=function(x)length(na.omit(x))))
+					} else {
+						cnttab <- rbind(cnttab, aggregate(d[,1:(ncol(d)-1)], by=list(d[,ncol(d)]), FUN=length))				
+					}
 				}
-			
 				if (length(alltab) > 10000) {
 					alltab <- aggregate(alltab[,2:ncol(alltab)], by=list(alltab[,1]), FUN=fun, na.rm=na.rm) 
 					if (counts) {
@@ -85,5 +90,3 @@ zonal <- function(x, zones, stat='mean', digits=0, na.rm=TRUE, progress='') {
 
 	return(alltab)
 }
-
-
